# hzdatasdk Package

This is a simple example package. You can use
[Github-flavored Markdown](https://guides.github.com/features/mastering-markdown/)
to write your content.

列举了hzdata相关的一些内容

项目背景:

	hzdata提供了一套python的sdk
	使用者在集成了sdk之后，可以通过接口直接拉取数据,返回
	的数据大都为pandas.dataframe、numpy.array等格式。

